@@ -1,12 +1,18 @@
 #![allow(bad_style)]
 
 extern crate core_foundation_sys;
+extern crate libc;
 
-#[cfg_attr(any(target_os = "macos", target_os = "ios"), link(name = "Security", kind = "framework"))]
+#[cfg_attr(
+    any(target_os = "macos", target_os = "ios"),
+    link(name = "Security", kind = "framework")
+)]
 extern "C" {}
 
 #[cfg(target_os = "macos")]
 pub mod access;
+#[cfg(target_os = "macos")]
+pub mod authorization;
 pub mod base;
 pub mod certificate;
 #[cfg(target_os = "macos")]
@@ -30,3 +36,5 @@ pub mod secure_transport;
 #[cfg(target_os = "macos")]
 pub mod transform;
 pub mod trust;
+#[cfg(target_os = "macos")]
+pub mod trust_settings;
