@@ -1,7 +1,7 @@
 use core_foundation_sys::base::{Boolean, CFTypeID};
 use core_foundation_sys::string::CFStringRef;
 
-use base::SecPolicyRef;
+use crate::base::SecPolicyRef;
 
 extern "C" {
     pub fn SecPolicyCreateSSL(server: Boolean, hostname: CFStringRef) -> SecPolicyRef;
